@@ -1,13 +1,16 @@
-var flag;
-ws.onmessage = function(evt) {
+// automatically refresh the page when necessary (R will send a message to ws)
+((interval, path, ws) => {
+let flag;
+ws.onmessage = e => {
   flag = true;
-  if (evt.data === 'false' || evt.data === 'null') return;
+  if (e.data === 'false' || e.data === 'null') return;
   // fire a servr:reload event
   Event && document.dispatchEvent(new Event('servr:reload'));
   location.reload();
 };
-setInterval(function() {
+setInterval(() => {
   if (flag === false || ws.readyState !== ws.OPEN) return;
   flag = false;  // prevent ws message if R hasn't responded yet
-  ws.send('{}');
-}, !!SERVR_INTERVAL);
+  ws.send(path);
+}, interval);
+})
